==> anwiba-commons-json-1.0.52-sources.jar: net/anwiba/commons/json/schema/v1_0/NumberProperty.java <==
//Copyright (c) 2016 by Andreas W. Bartels (bartels@anwiba.de)
package net.anwiba.commons.json.schema.v1_0;

import com.fasterxml.jackson.annotation.JsonProperty;

public class NumberProperty
    extends Property
{

    private final String type = "number";
    private Number _default = null;
    private String format = null;
    private Integer maxLength = null;
    private Double minimum = null;
    private Double maximum = null;
    private Double exclusiveMinimum = null;
    private Double exclusiveMaximum = null;
    private Integer divisibleBy = null;
    private Number[] _enum = null;

    @JsonProperty("type")
    public void setType(final String type) {
    }

    @JsonProperty("type")
    public String getType() {
        return this.type;
    }

    @JsonProperty("default")
    public void setDefault(final Number _default) {
        this._default = _default;
    }

    @JsonProperty("default")
    public Number getDefault() {
        return this._default;
    }

    @JsonProperty("format")
    public void setFormat(final String format) {
        this.format = format;
    }

    @JsonProperty("format")
    public String getFormat() {
        return this.format;
    }

    @JsonProperty("maxLength")
    public void setMaxLength(final Integer maxLength) {
        this.maxLength = maxLength;
    }

    @JsonProperty("maxLength")
    public Integer getMaxLength() {
        return this.maxLength;
    }

    @JsonProperty("minimum")
    public void setMinimum(final Double minimum) {
        this.minimum = minimum;
    }

    @JsonProperty("minimum")
    public Double getMinimum() {
        return this.minimum;
    }

    @JsonProperty("maximum")
    public void setMaximum(final Double maximum) {
        this.maximum = maximum;
    }

    @JsonProperty("maximum")
    public Double getMaximum() {
        return this.maximum;
    }

    @JsonProperty("exclusiveMinimum")
    public void setExclusiveMinimum(final Double exclusiveMinimum) {
        this.exclusiveMinimum = exclusiveMinimum;
    }

    @JsonProperty("exclusiveMinimum")
    public Double getExclusiveMinimum() {
        return this.exclusiveMinimum;
    }

    @JsonProperty("exclusiveMaximum")
    public void setExclusiveMaximum(final Double exclusiveMaximum) {
        this.exclusiveMaximum = exclusiveMaximum;
    }

    @JsonProperty("exclusiveMaximum")
    public Double getExclusiveMaximum() {
        return this.exclusiveMaximum;
    }

    @JsonProperty("divisibleBy")
    public void setDivisibleBy(final Integer divisibleBy) {
        this.divisibleBy = divisibleBy;
    }

    @JsonProperty("divisibleBy")
    public Integer getDivisibleBy() {
        return this.divisibleBy;
    }

    @JsonProperty("enum")
    public void setEnum(final Number[] _enum) {
        this._enum = _enum;
    }

    @JsonProperty("enum")
    public Number[] getEnum() {
        return this._enum;
    }

}

==> anwiba-commons-json-1.1.121-sources.jar: net/anwiba/commons/json/schema/v1_0/NumberProperty.java <==
//Copyright (c) 2012 by Andreas W. Bartels
package net.anwiba.commons.json.schema.v1_0;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;

public class NumberProperty
    extends Property
{

    private final String type = "number";
    private Number _default = null;
    private String format = null;
    private Integer maxLength = null;
    private Double minimum = null;
    private Double maximum = null;
    private Double exclusiveMinimum = null;
    private Double exclusiveMaximum = null;
    private Integer divisibleBy = null;
    private Number[] _enum = null;

    @JsonIgnore
    public void setType(final String type) {
    }

    @JsonIgnore
    public String getType() {
        return this.type;
    }

    @JsonProperty("default")
    public void setDefault(final Number _default) {
        this._default = _default;
    }

    @JsonProperty("default")
    public Number getDefault() {
        return this._default;
    }

    @JsonProperty("format")
    public void setFormat(final String format) {
        this.format = format;
    }

    @JsonProperty("format")
    public String getFormat() {
        return this.format;
    }

    @JsonProperty("maxLength")
    public void setMaxLength(final Integer maxLength) {
        this.maxLength = maxLength;
    }

    @JsonProperty("maxLength")
    public Integer getMaxLength() {
        return this.maxLength;
    }

    @JsonProperty("minimum")
    public void setMinimum(final Double minimum) {
        this.minimum = minimum;
    }

    @JsonProperty("minimum")
    public Double getMinimum() {
        return this.minimum;
    }

    @JsonProperty("maximum")
    public void setMaximum(final Double maximum) {
        this.maximum = maximum;
    }

    @JsonProperty("maximum")
    public Double getMaximum() {
        return this.maximum;
    }

    @JsonProperty("exclusiveMinimum")
    public void setExclusiveMinimum(final Double exclusiveMinimum) {
        this.exclusiveMinimum = exclusiveMinimum;
    }

    @JsonProperty("exclusiveMinimum")
    public Double getExclusiveMinimum() {
        return this.exclusiveMinimum;
    }

    @JsonProperty("exclusiveMaximum")
    public void setExclusiveMaximum(final Double exclusiveMaximum) {
        this.exclusiveMaximum = exclusiveMaximum;
    }

    @JsonProperty("exclusiveMaximum")
    public Double getExclusiveMaximum() {
        return this.exclusiveMaximum;
    }

    @JsonProperty("divisibleBy")
    public void setDivisibleBy(final Integer divisibleBy) {
        this.divisibleBy = divisibleBy;
    }

    @JsonProperty("divisibleBy")
    public Integer getDivisibleBy() {
        return this.divisibleBy;
    }

    @JsonProperty("enum")
    public void setEnum(final Number[] _enum) {
        this._enum = _enum;
    }

    @JsonProperty("enum")
    public Number[] getEnum() {
        return this._enum;
    }

}
